@@ -99,9 +99,7 @@ module Sawyer
       assert !res.respond_to?(:b)
       assert !res.respond_to?(:b=)
       assert_nil res.b
-      assert_nothing_raised do
-        res.b
-      end
+      res.b
     end
 
     def test_dynamic_attribute_methods_from_setter
@@ -128,6 +126,12 @@ module Sawyer
       assert_equal hash, res.to_h
     end
 
+    def test_to_h_with_nesting
+      res = Resource.new @agent, :a => {:b => 1}
+      hash = {:a => {:b => 1}}
+      assert_equal hash, res.to_h
+    end
+
     def test_to_attrs_for_sawyer_resource_arrays
       res = Resource.new @agent, :a => 1, :b => [Resource.new(@agent, :a => 2)]
       hash = {:a => 1, :b => [{:a => 2}]}
@@ -163,24 +167,22 @@ module Sawyer
     end
 
     def test_handle_yaml_dump
-      assert_nothing_raised do
-        require 'yaml'
-        res = Resource.new @agent, :a => 1
-        YAML.dump(res)
-      end
+      return unless supports_yaml?
+
+      require 'yaml'
+      res = Resource.new @agent, :a => 1
+      YAML.dump(res)
     end
 
     def test_handle_marshal_dump
-      assert_nothing_raised do
-        dump = Marshal.dump(Resource.new(@agent, :a => 1))
-        resource = Marshal.load(dump)
-        assert_equal 1, resource.a
-      end
+      dump = Marshal.dump(Resource.new(@agent, :a => 1))
+      resource = Marshal.load(dump)
+      assert_equal 1, resource.a
     end
 
     def test_inspect
       resource = Resource.new @agent, :a => 1
-      assert_equal "{:a=>1}\n", resource.inspect
+      assert_equal "{:a=>1}", resource.inspect.strip
     end
 
     def test_each
